import 'dart:core';
import 'package:chopper/chopper.dart';

part 'api_service.chopper.dart';

@ChopperApi()
abstract class ApiService extends ChopperService {
  // Download IPFS objects
  @Get(path: '/get?arg={cid}')
  Future<Response> getIPFS(@Path() String cid);

  @Get(path: '/dat/get?arg={cid}')
  Future<Response> getDag(@Path() String cid);

  @Get(path: '/block/get?arg={cid}')
  Future<Response> getBlock(@Path() String cid);

  @Get(path: '/block/stat?arg={key}')
  Future<Response> getBlockStat(@Path() String cid);

  // Show IPFS object data
  @Get(path: '/cat?arg={cid}')
  Future<Response> getCat(@Path() String cid);

  @Get(path: '/dag/resolve?arg={cid}')
  Future<Response> getDagResolve(@Path() String cid);

  @Get(path: '/object/data?arg={cid}')
  Future<Response> getObjectData(@Path() String cid);

  //Get and serialize the DAG node named by key
  @Get(path: '/object/get?arg={cid}')
  Future<Response> getObject(@Path() String cid);

  @Get(path: '/object/stat?arg={cid}')
  Future<Response> getObjectStat(@Path() String cid);

  @Get(path: '/object/get?arg={cid}')
  Future<Response> pinObject(@Path() String cid);

  @Post(path: '/pubsub/pub?arg={topic}&arg={message}')
  Future<Response> pubMsg(@Path() String topic, String message);


  static ApiService create() {
    final client = ChopperClient(
        baseUrl: 'http://localhost:5001/api/v0/',
        services: [
          _$ApiService(),
        ],
        converter: JsonConverter(),
        );
    return _$ApiService(client);
  }
}